# vim: set fileencoding=utf-8 :
"""OpScripts utilities library
"""
# Standard Library
from __future__ import print_function
import logging
import os
import random
import select
import sys


def request_confirmation(timeout=30):
    """Request the operator input the displayed random number to confirm the
    script should make the changes requested. Each attempt fails if the
    timeout is reached.

    Exits with an error after five failures.
    """
    try:
        timeout = float(timeout)
    except:
        logging.error("request_confirmation timeout must be a number")
        sys.exit(1)
    random_int = random.randint(10000, 99999)
    message = ("To continue, please enter the number '%d' within %d"
               " seconds:" % (random_int, timeout))
    i = 0
    while i < 5:
        i += 1
        print(message,)
        read_obj, w, x = select.select([sys.stdin], list(), list(), timeout)
        if read_obj:
            response = sys.stdin.readline().strip()
            try:
                response = int(response)
            except ValueError:
                pass
            except:
                raise
            if response == random_int:
                return
    logging.error("Failed to provide confirmation input.")
    sys.exit(os.EX_NOPERM)


def verify_root():
    """Verify script is being run as root.
    """
    if not os.geteuid() == 0:
        logging.error("Must be root or equivalent (ex. sudo).")
        sys.exit(os.EX_NOPERM)
